# -----------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# -----------------------------------------------------------------------------

"""
Defines constants for JSON keys.
"""

# All
_PROPERTIES = 'properties'
_ICON_URI = 'iconUri'
_CONNECTION_PARAMETERS = 'connectionParameters'

# Save
_API_DEFINITIONS = 'apiDefinitions'
_ORIGINAL_SWAGGER_URL = 'originalSwaggerUrl'
_ICON_BRAND_COLOR = 'iconBrandColor'
_CAPABILITIES = 'capabilities'
_POLICY_TEMPLATE_INSTANCES = 'policyTemplateInstances'

# Create update
_OPEN_API_DEFINITION = 'openApiDefinition'
_ENVIRONMENT = 'environment'
_BACKEND_SERVICE = 'backendService'
_SERVICE_URL = 'serviceUrl'
_SCHEMES = 'schemes'
_HOST = 'host'
_BASE_PATH = 'basePath'
_SHARED_ACCESS_SIGNATURE = 'sharedAccessSignature'
_DESCRIPTION = 'description'
_INFO = 'info'
_TITLE = 'title'
_TOKEN = 'token'
_OAUTH_SETTINGS = 'oAuthSettings'
_CLIENT_SECRET = 'clientSecret'
_DISPLAY_NAME = 'displayName'
_NAME = 'name'
