# -----------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# -----------------------------------------------------------------------------

"""
Initializer
"""

__VERSION__ = '0.0.13'
__CLI_NAME__ = 'paconn'

# Commands
_COMMAND_GROUP = ''
_LOGIN = 'login'
_DOWNLOAD = 'download'
_CREATE = 'create'
_UPDATE = 'update'
_VALIDATE = 'validate'
